InbandFec

Enum InbandFec 

#[repr(i32)]
pub enum InbandFec { Off = 0, Mode1 = 1, Mode2 = 2, }
Possible values of inband forward error correction configuration.

Variants



Off = 0

Inband FEC disabled (default)



Mode1 = 1

Inband FEC enabled.

If the packet loss rate is sufficiently high, Opus will automatically switch to SILK even at high rates to enable use of that FEC.



Mode2 = 2

Inband FEC enabled, but does not necessarily switch to SILK if we have music.